@@ -9,6 +9,9 @@ Also the modules *must* define a BACKENDS dictionary with the backend name
 (which is used for URLs matching) and Auth class, otherwise it won't be
 enabled.
 """
+import logging
+logger = logging.getLogger(__name__)
+
 from os import walk
 from os.path import basename
 from uuid import uuid4
@@ -35,6 +38,7 @@ from social_auth.models import UserSocialAuth
 from social_auth.store import DjangoOpenIDStore
 from social_auth.signals import pre_update, socialauth_registered, \
                                 socialauth_not_registered
+from social_auth.utils import sanitize_log_data
 
 
 # OpenID configuration
@@ -133,6 +137,8 @@ class SocialAuthBackend(ModelBackend):
                         user = None
                 if not user:
                     username = self.username(details)
+                    logger.debug('Creating new user with username %s and email %s',
+                                 username, sanitize_log_data(email))
                     user = User.objects.create_user(username=username,
                                                     email=email)
                     is_new = True
@@ -220,6 +226,9 @@ class SocialAuthBackend(ModelBackend):
 
         # check if values update should be left to signals handlers only
         if not CHANGE_SIGNAL_ONLY:
+            logger.debug('Updating user details for user %s', user,
+                         extra=dict(data=details))
+
             for name, value in details.iteritems():
                 # do not update username, it was already generated by
                 # self.username(...) and loaded in given instance
@@ -665,14 +674,20 @@ class BaseOAuth2(BaseOAuth):
     """
     AUTHORIZATION_URL = None
     ACCESS_TOKEN_URL = None
+    SCOPE_SEPARATOR = ' '
+    RESPONSE_TYPE = 'code'
 
     def auth_url(self):
         """Return redirect url"""
         client_id, client_secret = self.get_key_and_secret()
-        args = {'client_id': client_id,
-                'scope': ' '.join(self.get_scope()),
-                'redirect_uri': self.redirect_uri,
-                'response_type': 'code'}  # requesting code
+        args = {'client_id': client_id, 'redirect_uri': self.redirect_uri}
+
+        scope = self.get_scope()
+        if scope:
+            args['scope'] = self.SCOPE_SEPARATOR.join(self.get_scope())
+        if self.RESPONSE_TYPE:
+            args['response_type'] = self.RESPONSE_TYPE
+
         args.update(self.auth_extra_arguments())
         return self.AUTHORIZATION_URL + '?' + urlencode(args)
 
@@ -731,6 +746,7 @@ def get_backends():
         try:
             mod = import_module(mod_name)
         except ImportError:
+            logger.exception('Error importing %s', mod_name)
             continue
 
         for directory, subdir, files in walk(mod.__path__[0]):
