@@ -4,6 +4,9 @@ LiveJournal OpenID support.
 This contribution adds support for LiveJournal OpenID service in the form
 username.livejournal.com. Username is retrieved from the identity url.
 """
+import logging
+logger = logging.getLogger(__name__)
+
 import urlparse
 
 from social_auth.backends import OpenIDBackend, OpenIdAuth, USERNAME
@@ -38,7 +41,7 @@ class LiveJournalAuth(OpenIdAuth):
     def openid_url(self):
         """Returns LiveJournal authentication URL"""
         if not self.data.get(LIVEJOURNAL_USER_FIELD):
-            raise ValueError, 'Missing LiveJournal user identifier'
+            raise ValueError('Missing LiveJournal user identifier')
         return LIVEJOURNAL_URL % self.data[LIVEJOURNAL_USER_FIELD]
 
 
