@@ -1,7 +1,24 @@
 import urlparse
 from collections import defaultdict
 
-from social_auth.backends import BACKENDS, OpenIdAuth, BaseOAuth, BaseOAuth2
+
+def sanitize_log_data(secret, data=None, leave_characters=4):
+    """
+    Clean private/secret data from log statements and other data.
+
+    Assumes data and secret are strings. Replaces all but the first
+    `leave_characters` of `secret`, as found in `data`, with '*'.
+
+    If no data is given, all but the first `leave_characters` of secret
+    are simply replaced and returned.
+    """
+    replace_secret = (secret[:leave_characters] +
+                      (len(secret) - leave_characters) * '*')
+
+    if data:
+        return data.replace(secret, replace_secret)
+
+    return replace_secret
 
 
 def sanitize_redirect(host, redirect_to):
@@ -43,6 +60,11 @@ def sanitize_redirect(host, redirect_to):
 
 def group_backend_by_type(items, key=lambda x: x):
     """Group items by backend type."""
+
+    # Beware of cyclical imports!
+    from social_auth.backends import \
+        BACKENDS, OpenIdAuth, BaseOAuth, BaseOAuth2
+
     result = defaultdict(list)
 
     for item in items:
